;; Generated package description from mathsheet.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "mathsheet" "1.2.0.20250705.223649" "Generate dynamic math worksheets" '((peg "1.0") (emacs "28.1")) :commit "344d10db24358c0974bdd9fffc2e3f8d960fbb07" :authors '(("Ian Martins" . "ianxm@jhu.edu")) :maintainer '("Ian Martins" . "ianxm@jhu.edu") :keywords '("tools" "education" "math") :url "https://gitlab.com/ianxm/mathsheet")
